/*
   Do not modify this file.
*/

import java.util.concurrent.TimeUnit;
import java.util.Random;

/**
   Each time that a Consumer should consume an item,
   it randomly chooses a buffer to get an item from.
*/
public class Consumer_v1 implements Runnable
{
   private final Buffer_Bounded[] bufs;
   private final int ms;
   private final Random random = new Random();

   /**
      Create a consumer that uses the given array of bounded buffers.

      Each time the consumer wants to consume an item the consumer will
      randomly choose a buffer from the array of bounded buffers and call
      that buffer's get() method.

      After successfully getting an item from a buffer, the consumer
      should sleep for the given number of milliseconds.

      @param buf  array of {@link Buffer_Bounded} objects
      @param ms   milliseconds of delay after consuming one item
   */
   public Consumer_v1(final Buffer_Bounded[] bufs, final int ms)
   {
      this.bufs = bufs;
      this.ms = ms;
   }


   @Override
   public void run()
   {
      try
      {
         while(! Thread.currentThread().isInterrupted())
         {
            int i = random.nextInt(bufs.length);
            bufs[i].get();
            Thread.sleep(ms); // Slow down the consumer.
         }
      }
      catch (InterruptedException e)
      {
         // Print a stack trace and then the thread dies.
         e.printStackTrace();
      }
   }
}
