/*
   Do not modify this file.
*/

import java.util.Random;

/**
   Each time that a Producer should produce an item,
   it randomly chooses a buffer to put the item into.
*/
public class Producer_v1 implements Runnable
{
   private final Buffer_Bounded[] bufs;
   private final int ms;
   private final Random random = new Random();

   /**
      Create a producer that uses the given array of bounded buffers.

      Each time the producer wants to produce an item the producer will
      randomly choose a buffer from the array of bounded buffers and call
      that buffer's put() method.

      After successfully putting an item into a buffer, the producer
      should sleep for the given number of milliseconds.

      @param buf  array of {@link Buffer_Bounded} objects
      @param ms   milliseconds of delay after producing one item
   */
   public Producer_v1(final Buffer_Bounded[] bufs, final int ms)
   {
      this.bufs = bufs;
      this.ms = ms;
   }


   @Override
   public void run()
   {
      try
      {
         while(! Thread.currentThread().isInterrupted())
         {
            int i = random.nextInt(bufs.length);
            bufs[i].put();
            Thread.sleep(ms); // Slow down the producer.
         }
      }
      catch (InterruptedException e)
      {
         // Print a stack trace and then the thread dies.
         e.printStackTrace();
      }
   }
}
